{% extends "base.html" %} {% set active_page = "history" %} {% block title %}History{% endblock %} {% block content %}

Session History

Date | Animal ID | Behaviour | Session Data
--- | --- | --- | ---
03/01/2020 | sub-mouse1034 | Single Target |
04/01/2020 | sub-mouse1044 | Single Target |
04/01/2020 | sub-mouse1034 | Single Target |
05/01/2020 | sub-mouse1034 | Visual Discrimination |

{% endblock %}